=====
nlgen
=====

.. image::https://travis-ci.org/toumorokoshi/nlgen/settings#
    :alt: build status
    :target: https://travis-ci.org/toumorokoshi/nlgen

Natural Language Generator for Python

-------
Summary
-------

nlgen provides tools that help with natural language generation. nlgen currently features:

- a featured context free grammar representation and generator.

------------
Documentation
------------

Currently, nlgen is in a very early alpha. The best documentation at this time is the unit tests:

How to use the context-free grammar programatically:

- CFG example: https://github.com/toumorokoshi/nlgen/blob/master/nlgen/tests/cfg/test_full.py
- Using the text representation of a CFG: https://github.com/toumorokoshi/nlgen/blob/master/nlgen/tests/cfg/test_markup_parser.py
